==> jc-1.4.0.tar.gz: scm/scmAsciiCP.h <==
// class scm.scmAsciiCP

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class e3e6f67f2c0323e6 scm_scmAsciiCP

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmAsciiCP_H_
#define _JC_scm_scmAsciiCP_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmAsciiCP$sub_refs	_jc_scm_scmAsciiCP$sub_refs;
typedef struct _jc_scm_scmAsciiCP$sub_nonrefs	_jc_scm_scmAsciiCP$sub_nonrefs;
typedef struct _jc_scm_scmAsciiCP$refs	_jc_scm_scmAsciiCP$refs;
typedef struct _jc_scm_scmAsciiCP$nonrefs	_jc_scm_scmAsciiCP$nonrefs;
typedef struct _jc_scm_scmAsciiCP$object	_jc_scm_scmAsciiCP$object;

typedef const struct _jc_scm_scmAsciiCP$vmethods	_jc_scm_scmAsciiCP$vmethods;
typedef const struct _jc_scm_scmAsciiCP$vtable	_jc_scm_scmAsciiCP$vtable;
typedef const struct _jc_scm_scmAsciiCP$vtype	_jc_scm_scmAsciiCP$vtype;

// Constructors
extern void _jc_scm_scmAsciiCP$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmAsciiCP$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_scmAsciiCP$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmAsciiCP$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_scmAsciiCP$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmAsciiCP$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_scmAsciiCP$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmAsciiCP$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmAsciiCP$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmAsciiCP$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmAsciiCP$object *);
};

// Vtable
struct _jc_scm_scmAsciiCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmAsciiCP$vmethods	scm_scmAsciiCP;
};

// Vtype
struct _jc_scm_scmAsciiCP$vtype {
	_jc_type			type;
	_jc_scm_scmAsciiCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmAsciiCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmAsciiCP$refs {
    _jc_scm_scmAsciiCP$sub_refs	scm_scmAsciiCP;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmAsciiCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmAsciiCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmAsciiCP$sub_nonrefs	scm_scmAsciiCP;
};

// Object instance structure
struct _jc_scm_scmAsciiCP$object {
	_jc_scm_scmAsciiCP$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmAsciiCP$vtype	*vtype;
	_jc_scm_scmAsciiCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmAsciiCP$vtype _jc_scm_scmAsciiCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmAsciiCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmAsciiCP$class_object;

#endif	/* _JC_scm_scmAsciiCP_H_ */

==> jc-1.4.6.tar.gz: scm/scmAsciiCP.h <==
// class scm.scmAsciiCP

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class e3e6f67f2c0323e6 scm_scmAsciiCP

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmAsciiCP_H_
#define _JC_scm_scmAsciiCP_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmAsciiCP$sub_refs	_jc_scm_scmAsciiCP$sub_refs;
typedef struct _jc_scm_scmAsciiCP$sub_nonrefs	_jc_scm_scmAsciiCP$sub_nonrefs;
typedef struct _jc_scm_scmAsciiCP$refs	_jc_scm_scmAsciiCP$refs;
typedef struct _jc_scm_scmAsciiCP$nonrefs	_jc_scm_scmAsciiCP$nonrefs;
typedef struct _jc_scm_scmAsciiCP$object	_jc_scm_scmAsciiCP$object;

typedef const struct _jc_scm_scmAsciiCP$vmethods	_jc_scm_scmAsciiCP$vmethods;
typedef const struct _jc_scm_scmAsciiCP$vtable	_jc_scm_scmAsciiCP$vtable;
typedef const struct _jc_scm_scmAsciiCP$vtype	_jc_scm_scmAsciiCP$vtype;

// Constructors
extern void _jc_scm_scmAsciiCP$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmAsciiCP$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_scmAsciiCP$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmAsciiCP$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_scmAsciiCP$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmAsciiCP$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_scmAsciiCP$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmAsciiCP$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmAsciiCP$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmAsciiCP$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmAsciiCP$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_scmAsciiCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmAsciiCP$vmethods	scm_scmAsciiCP;
};

// Vtype
struct _jc_scm_scmAsciiCP$vtype {
	_jc_type			type;
	_jc_scm_scmAsciiCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmAsciiCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmAsciiCP$refs {
    _jc_scm_scmAsciiCP$sub_refs	scm_scmAsciiCP;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmAsciiCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmAsciiCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmAsciiCP$sub_nonrefs	scm_scmAsciiCP;
};

// Object instance structure
struct _jc_scm_scmAsciiCP$object {
	_jc_scm_scmAsciiCP$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmAsciiCP$vtype	*vtype;
	_jc_scm_scmAsciiCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmAsciiCP$vtype _jc_scm_scmAsciiCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmAsciiCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmAsciiCP$class_object;

#endif	/* _JC_scm_scmAsciiCP_H_ */
